@@ -1,4 +1,4 @@
-from typing import Callable, Dict, Hashable, List
+from typing import Callable, Dict, Hashable, List, Optional
 
 from ..typing import T_Dispatcher
 from .decorator import Decorator
@@ -14,8 +14,8 @@ class ExecTarget:
     def __init__(
         self,
         callable: Callable,
-        inline_dispatchers: List[T_Dispatcher] = None,
-        decorators: List[Decorator] = None,
+        inline_dispatchers: Optional[List[T_Dispatcher]] = None,
+        decorators: Optional[List[Decorator]] = None,
     ):
         self.callable = callable
         self.dispatchers = inline_dispatchers or []
