@@ -27,7 +27,7 @@ class InterruptControl:
         self.broadcast = broadcast
 
     async def wait(
-        self, waiter: Waiter, priority: Optional[Union[int, Priority]] = None, timeout: float = None, **kwargs
+        self, waiter: Waiter, priority: Optional[Union[int, Priority]] = None, timeout: Optional[float] = None, **kwargs
     ):
         """生成一一次性使用的监听器并将其挂载, 该监听器用于获取特定类型的事件, 并根据设定对事件进行过滤;
         当获取到符合条件的对象时, 堵塞将被解除, 同时该方法返回从监听器得到的值.
